diff Core/SQLite/StatementReference.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents db4d996ea264
children c996319e90bc
line wrap: on
line diff
--- a/Core/SQLite/StatementReference.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/SQLite/StatementReference.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -36,12 +36,12 @@
 
 #include "StatementReference.h"
 
-#include "../PalantirException.h"
+#include "../PalanthirException.h"
 
 #include <cassert>
 #include "sqlite3.h"
 
-namespace Palantir
+namespace Palanthir
 {
   namespace SQLite
   {
@@ -63,7 +63,7 @@
     {
       if (database == NULL || sql == NULL)
       {
-        throw PalantirException(ErrorCode_ParameterOutOfRange);
+        throw PalanthirException(ErrorCode_ParameterOutOfRange);
       }
 
       root_ = NULL;
@@ -72,7 +72,7 @@
       int error = sqlite3_prepare_v2(database, sql, -1, &statement_, NULL);
       if (error != SQLITE_OK)
       {
-        throw PalantirException("SQLite: " + std::string(sqlite3_errmsg(database)));
+        throw PalanthirException("SQLite: " + std::string(sqlite3_errmsg(database)));
       }
 
       assert(IsRoot());
@@ -104,7 +104,7 @@
         if (refCount_ != 0)
         {
           // There remain references to this object
-          throw PalantirException(ErrorCode_InternalError);
+          throw PalanthirException(ErrorCode_InternalError);
         }
         else if (statement_ != NULL)
         {
@@ -115,7 +115,7 @@
       {
         if (root_->refCount_ == 0)
         {
-          throw PalantirException(ErrorCode_InternalError);
+          throw PalanthirException(ErrorCode_InternalError);
         }
         else
         {
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium